from setuptools import setup, find_packages
 
setup(
    name='geometry_alrandis',
    version='0.3.0',
    author='me',
    author_email='alrandisisdernii@gmail.com',
    description='This  is very useful package',
    long_description=open('README.md').read(),
    packages=find_packages()
)